CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
59 lines
1.6 KiB
C++
59 lines
1.6 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <hip_test_defgroups.hh>
|
|
#include "printf_common.h" // NOLINT
|
|
|
|
__global__ void test_kernel_star() {
|
|
printf("%*d\n", 16, 42);
|
|
printf("%.*d\n", 8, 42);
|
|
printf("%*.*d\n", -16, 8, 42);
|
|
printf("%*.*f %s * %.*s\n", 16, 8, 123.456, "hello", 5, "worldxyz");
|
|
}
|
|
/**
|
|
* @addtogroup printf printf
|
|
* @{
|
|
* @ingroup PrintfTest
|
|
* `int printf()` -
|
|
* Method to print the content on output device.
|
|
*/
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Test case to verify the additional arguments (*) in the printf API
|
|
* Test source
|
|
* ------------------------
|
|
* - catch/unit/printf/hipPrintfStar.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 6.2
|
|
*/
|
|
HIP_TEST_CASE(Unit_Printf_PrintfStar) {
|
|
int pcieAtomic = 0;
|
|
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
|
if (!pcieAtomic) {
|
|
HIP_SKIP_TEST(HipTest::SkipReason::kPcieAtomicUnsupported);
|
|
}
|
|
std::string reference =
|
|
std::string(R"here( 42
|
|
00000042
|
|
)here") +
|
|
std::string("00000042") + std::string(8, ' ') + "\n" +
|
|
std::string(" 123.45600000 hello * world\n");
|
|
CaptureStream captured(stdout);
|
|
hipLaunchKernelGGL(test_kernel_star, dim3(1), dim3(1), 0, 0);
|
|
HIP_CHECK(hipStreamSynchronize(0));
|
|
auto CapturedData = captured.getCapturedData();
|
|
std::string device_output = captured.gulp(CapturedData);
|
|
REQUIRE(device_output == reference);
|
|
}
|
|
|
|
/**
|
|
* End doxygen group PrintfTest.
|
|
* @}
|
|
*/
|